@@ -27,7 +27,8 @@ LearnerClassifLogReg = R6Class("LearnerClassifLogReg", inherit = LearnerClassif,
         predict_types = c("response", "prob"),
         feature_types = c("logical", "integer", "numeric", "character", "factor", "ordered"),
         properties = c("weights", "twoclass"),
-        packages = "stats"
+        packages = "stats",
+        man = "mlr3learners::mlr_learners_classif.log_reg"
       )
     },
 
